Summary: Extra tools for rpm-ostree
Name: rpm-ostree-toolbox
Version: 2017.2
Release: 4%{?dist}
#VCS: https://github.com/cgwalters/rpm-ostree-toolbox
# This tarball is generated via "make -C packaging -f Makefile.dist-packaging dist-snapshot"
# which is really just a wrapper for "git archive".
# It doesn't follow the Github guidelines because they only work for
# github; the infrastructure above is generic for any git repository.
ExcludeArch: ppc64
Source0: %{name}-%{version}.tar.xz
License: LGPLv2+
BuildRequires: git
URL: https://github.com/cgwalters/rpm-ostree-toolbox
# We always run autogen.sh
BuildRequires: autoconf automake libtool
# For docs
BuildRequires: gtk-doc
BuildRequires: gnome-common
BuildRequires: pkgconfig(ostree-1)
BuildRequires: pkgconfig(libgsystem)
BuildRequires: pkgconfig(json-glib-1.0)

%global unprivileged_user rpmostreecompose
%global unprivileged_group rpmostreecompose

Requires: python
Requires: python-iniparse
# Needed for installer generation
Requires: python-urlgrabber
Requires: pygobject2 pygobject3-base
Requires: libvirt-python rpm-ostree
Requires: docker

Requires: libgsystem
Requires: libguestfs-tools-c
Requires: libguestfs-gobject
# Needed for libguests
Requires: kernel

Requires: lorax
# Imagefactory
Requires: imagefactory >= 1.1.6-1
Requires: imagefactory-plugins-TinMan >= 1.1.6-1
Requires: imagefactory-plugins-OVA >= 1.1.6-1
Requires: imagefactory-plugins-vSphere >= 1.1.6-1
Requires: imagefactory-plugins-RHEVM >= 1.1.6-1
Requires: imagefactory-plugins-IndirectionCloud >= 1.1.6-1

%if 0%{?rhel}
%else
Requires: libguestfs-xfs
%endif
Requires(pre):  shadow-utils
Requires:       systemd-units
Requires(post): systemd-units

%description
Various utilities and scripts for working with rpm-ostree based
operating systems, particularly as virtual machines.

%prep
%autosetup -Sgit -n %{name}-%{version}

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p -c"

%pre
getent group %{unprivileged_group} >/dev/null || groupadd -r %{unprivileged_group}
getent passwd %{unprivileged_user} >/dev/null || \
  useradd -r -g %{unprivileged_group} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -c "RPM OStree Toolbox user" %{unprivileged_user}

%post
/bin/systemctl daemon-reload >/dev/null 2>&1 || :

%files
%doc COPYING README.md
%{_bindir}/rpm-ostree-toolbox
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*.gz

%dir %{_localstatedir}/lib/%{name}
%attr(0755,%{unprivileged_user},%{unprivileged_group}) %{_localstatedir}/lib/%{name}

%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2017.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2017.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2017.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed May 31 2017 Colin Walters <walters@verbum.org> - 2017.2-1
- New upstream version

* Tue May 30 2017 Colin Walters <walters@verbum.org> - 2017.1-1
- New upstream version

* Tue Apr 25 2017 bbaude <bbaude@redhat.com> - 2016.4-4
- toolbox requires docker; docker is not available for ppc64 due to no goland support BZ #1445493

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2016.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Dec 02 2016 walters@redhat.com - 2016.4-2
- Require libgsystem

* Mon May 02 2016 Colin Walters <walters@redhat.com> - 2016.1-2
- New upstream version

* Thu Apr 07 2016 David King <amigadave@amigadave.com> - 2015.12-4
- Require python-urlgrabber (#1324838)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2015.12-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Oct 02 2015 Colin Walters <walters@redhat.com> - 2015.12-2
- New upstream version

* Thu Aug 06 2015 Colin Walters <walters@redhat.com> - 2015.10-1
- New upstream version

* Thu Jul 16 2015 Colin Walters <walters@redhat.com> - 2015.9-2
- New upstream version

* Fri Jun 19 2015 Colin Walters <walters@redhat.com> - 2015.8-4
- Backport patch to avoid blowing away all remotes for CentOS

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2015.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 18 2015 Colin Walters <walters@redhat.com> - 2015.8-2
- New upstream release

* Wed Mar 25 2015 Colin Walters <walters@redhat.com> - 2015.7-3
- Change Requires to just docker per the rename

* Sat Feb 28 2015 Colin Walters <walters@redhat.com> - 2015.7-2
- New upstream release

* Sat Feb 21 2015 Colin Walters <walters@redhat.com> - 2015.6-2
- New upstream release

* Thu Feb 05 2015 Colin Walters <walters@redhat.com> - 2015.5-2
- New upstream release

* Wed Feb 04 2015 Colin Walters <walters@redhat.com> - 2015.4-2
- New upstream release

* Sat Jan 24 2015 Colin Walters <walters@redhat.com> - 2015.3-2
- New upstream release

* Tue Jan 20 2015 Colin Walters <walters@redhat.com> - 2015.2-2
- New upstream release

* Fri Jan 09 2015 Colin Walters <walters@redhat.com> - 2015.1-1
- New upstream release

* Fri Dec 19 2014 Colin Walters <walters@redhat.com> - 2014.110-4
- Only require docker on x86_64

* Fri Dec 19 2014 Colin Walters <walters@redhat.com> - 2014.110-2
- New upstream release

* Fri Dec 19 2014 Brent Baude <bbaude@redhat.com> - 2014.109-3
- Added new RPM dependancies

* Thu Dec 18 2014 Colin Walters <walters@redhat.com> - 2014.109-2
- New upstream release

* Sat Dec 13 2014 Colin Walters <walters@redhat.com> - 2014.108-2
- New upstream version

* Wed Nov 26 2014 Colin Walters <walters@redhat.com> - 2014.107-1
- New upstream version

* Tue Oct 28 2014 Colin Walters <walters@redhat.com> - 2014.106-3
- New upstream release

* Fri Oct 24 2014 Colin Walters <walters@redhat.com> - 2014.105-2
- New upstream release

* Sat May 24 2014 Colin Walters <walters@verbum.org> - 2014.11-1
- Initial package

